<?php
/*
Plugin Name: Oracle Cards
Plugin URI: https://emotionalonlinestorytelling.com/oracle-card-wordpress-plugin/
Description: Random oracle cards generation.
Author: Emotional Online Storytelling
Author URI: https://emotionalonlinestorytelling.com
Text Domain: oracle-cards
Domain Path: /languages/
Version: 0.1.0
*/
/*  Copyright 2020 Emotional Online Storytelling (email: info at emotionalonlinestorytelling.com)
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
*/

defined( 'ABSPATH' ) || exit; // Exit if accessed directly

// Definitions

define( 'EOS_CARDS_DIR', untrailingslashit( dirname( __FILE__ ) ) );
define( 'EOS_CARDS_URL', untrailingslashit( plugins_url( '', __FILE__ ) ) );
define( 'EOS_CARDS_ASSETS_URL',EOS_CARDS_URL.'/assets-4' );
define( 'EOS_CARDS_SLUG', plugin_basename( __FILE__ ) );
define( 'EOS_CARDS_PLUGIN_VERSION', '0.0.9'  );
define( 'EOS_CARDS_PLUGIN_FILE', __FILE__  );
define( 'EOS_CARDS_PLUGIN_BASE_NAME', untrailingslashit( plugin_basename( __FILE__ ) ) );
define( 'EOS_CARDS_PLUGIN_DOCU','https://emotionalonlinestorytelling.com/oracle-cards-wordpress-plugin/getting-start/' );
define( 'EOS_CARDS_PLUGIN_URI','https://emotionalonlinestorytelling.com/oracle-cards-wordpress-plugin/' );

$theme = wp_get_theme();
if( is_object( $theme ) && 'freesoul' === $theme->name ){
	define( 'EOS_CARDS_CURRENT_THEME','freesoul' );
}
else{
	define( 'EOS_CARDS_CURRENT_THEME','not_existing' );
}

//Files loading
if( is_admin() ){
	require EOS_CARDS_DIR . '/admin/cards-options.php'; //file including options for the landing page and mailchimp newsletter settings, custom taxonomies and general functions for the back-end
	require EOS_CARDS_DIR . '/admin/cards-metaboxes.php'; //file including the needed functions for the metaboxes
	if( defined( 'EOS_CARDS_PRO' ) && EOS_CARDS_PRO ){
		require( EOS_CARDS_DIR.'/admin/class-eos-oc-license-manager-client-pro.php' );
	}
}

add_shortcode( 'oracle_cards','eos_cards_oracle_cards' );
//Add shortcode
function eos_cards_oracle_cards( $atts ){
	$output = '';
	require EOS_CARDS_DIR.'/templates/shortcode.php';
	return $output;
}
if ( defined( 'DOING_AJAX' ) && DOING_AJAX ) {
	require EOS_CARDS_DIR . '/includes/cards-ajax-front.php'; //file including all ajax requests functions
}

//Loads the integration functions for page builders
if( function_exists( 'eosb_map' ) ){
	global $pagenow;
	if( ( $pagenow === 'post-new.php' || isset( $_GET['post'] ) && isset( $_GET['action'] ) && $_GET['action'] === 'edit' && is_admin() ) || ( defined( 'DOING_AJAX' ) && DOING_AJAX && is_admin() ) || isset( $_GET['eosb_editable'] ) || isset( $_GET['eosb_action'] ) ){
		require EOS_CARDS_DIR . '/integration/cards-eosb-integration.php';
	}
}
if( class_exists( 'Vc_Manager' ) ){
	require EOS_CARDS_DIR . '/integration/cards-vc-integration.php';
}

add_action( 'wpmu_new_blog', 'eos_cards_initialize_plugin' );
register_activation_hook( __FILE__, 'eos_cards_initialize_plugin' );
//Actions triggered after plugin activation or after a new site of a multisite installation is created (of course only if the plugin is active)
function eos_cards_initialize_plugin(){
	require EOS_CARDS_DIR . '/admin/cards-after-activation.php'; //to be updated
}
add_filter( 'load_textdomain_mofile', 'eos_cards_load_translation_file', 10, 2 );
//Loads plugin translation files
function eos_cards_load_translation_file( $mofile, $domain ) {
  if ( 'oracle-cards' === $domain ) {
    $mofile = EOS_CARDS_DIR . '/languages/oracle-cards-' . get_locale() . '.mo';
  }
  return $mofile;
}

add_action( 'init', 'eos_cards_load_dp_plugin_textdomain' );
//It loads plugin translation files
function eos_cards_load_dp_plugin_textdomain(){
	load_plugin_textdomain( 'oracle-cards',false,EOS_CARDS_DIR.'/languages/' );
}

add_action( 'init', 'eos_init_actions' );
/**
 *  Actions to be fired on init
 */
function eos_init_actions(){
	/*add costum post card*/
	register_post_type( 'card', array(
		'label' => __( 'Cards','oracle-cards' ),
		'labels' => array(
			'singular_name' => __( 'Card','ispiration-cards' ),
			'add_new' => __( 'Add single card','ispiration-cards' ),
			'add_new_item' => __( 'Add new card','ispiration-cards' ),
			'edit_item' => __( 'Edit card','ispiration-cards' ),
			'new_item' => __( 'New card','ispiration-cards' ),
			'view_item' => __( 'Show card','ispiration-cards' ),
			'search_items' => __( 'Search for cards','ispiration-cards' ),
			'not_found' => __( 'No cards were found','ispiration-cards' ),
			'not_found_in_trash' => __( 'No cards were found in Trash','ispiration-cards' ),
			'featured_image'        => __( 'Card front','oracle-cards' ),
			'set_featured_image'    => __( 'Set card front','oracle-cards' ),
			'remove_featured_image' => __( 'Remove card front','oracle-cards' ),
			'use_featured_image'    => __( 'Use as card front','oracle-cards' )
		),
		'supports' => array( 'title','thumbnail','editor' ),
		// 'public' => true,
		'show_ui' => true,
		'show_in_menu' => false,
		'show_in_nav_menus' => false,
		'capability_type' => 'post',
		'has_archive' => false,
		'taxonomies' => array( 'decks' ),
		'rewrite' => array(
			'slug' => 'card'
		),
		'query_var' => true,
		'publicly_queryable' => false
	) );
	$labels = array(
		'name'              => esc_html_x( 'Decks', 'taxonomy general name', 'oracle-cards' ),
		'singular_name'     => esc_html_x( 'Deck', 'taxonomy singular name', 'oracle-cards' ),
		'search_items'      => esc_html__( 'Search decks', 'oracle-cards' ),
		'all_items'         => esc_html__( 'All Decks', 'oracle-cards' ),
		'parent_item_colon' => esc_html__( 'Parent Deck:', 'oracle-cards'  ),
		'edit_item'         => esc_html__( 'Edit Deck', 'oracle-cards'  ),
		'update_item'       => esc_html__( 'Update Deck', 'oracle-cards'  ),
		'add_new_item'      => esc_html__( 'Add New Deck', 'oracle-cards'  ),
		'new_item_name'     => esc_html__( 'New Deck Name', 'oracle-cards'  ),
		'menu_name'         => esc_html__( 'Decks','oracle-cards' )
	);
	$args = array(
		'hierarchical'      => true,
		'show_in_nav_menus'	=> false,
		'menu_order'		=> false,
		'show_tagcloud'		=> false,
		'show_in_rest'		=> false,
		'labels'            => $labels,
		'show_ui'           => true,
		'publicly_queryable' => false,
		'show_admin_column' => true,
		'query_var'         => true,
	);
	register_taxonomy( 'decks','card', $args );
	add_filter( 'body_class','eos_cards_body_class' );
}

//Il loads the single card template checking first in the active theme
function eos_load_single_card_template( $template ) {
    global $post;
    if ( $post->post_type == 'card' ){
		$themeDir = get_stylesheet_directory();
        if( $template === $themeDir.'/single-card.php' ) return $template;
		if( file_exists( $themeDir.'/oracle-cards/single-card.php' ) ) return $themeDir.'/oracle-cards/single-card.php';
        return plugin_dir_path( __FILE__ ).'/templates/single-card.php';
    }
    return $template;
}
if( 'freesoul' !== EOS_CARDS_CURRENT_THEME ){
	add_filter( 'single_template', 'eos_load_single_card_template' );
}
add_action( 'wp_head','eos_cards_inline_style' );
//Add plugin inline style on frontend
function eos_cards_inline_style(){
	$style = '<style id="oracle-cards-css" type="text/css">';
	$style .= '.oracle-cards-wrapper{background-repeat:no-repeat;background-size:0 0;background-position:-9999px -9999px;background-image:url('.EOS_CARDS_ASSETS_URL.'/img/ajax-loader.gif)}';
	$style .= '.eos-cards-progress{background-size:48px 48px;background-position:center center}';
	$style .= '.eos-hidden{display:none !important}.center{text-align:center !important}.eos-margin-h-32{margin-top:32px !important}.oracle-cards .button{display:inline-block}.oracle-cards .button:hover{cursor:pointer}@media screen and (max-width:767px){.eos-card{max-width:90%;max-width:calc(100% - 100px)}.not-freesoul #eos-mix-cards-wrp .refresh-cards{margin-top:16px}}';
	$style .= '</style>';
	echo $style;
}

//Add body class
function eos_cards_body_class( $classes ){
	$classes[] = 'oracle-cards';
	if( 'freesoul' !== EOS_CARDS_CURRENT_THEME ){
		$classes[] = 'not-freesoul';
	}
	return $classes;
}
//Return plugin options
function eos_cards_get_options( $option_key = false ){
	if( !$option_key ){
		$option_key = 'eos-cards-options';
	}
	if( !is_multisite() ){
		return get_option( $option_key );
	}
	else{
		return get_blog_option( get_current_blog_id(),$option_key );
	}
}
//Update options in case of single or multisite installation.
function eos_cards_update_option( $option_key = false,$newvalue,$autoload = true ){
	if( !$option_key ){
		$option_key = 'eos-cards-options';
	}
	if( !is_multisite() ){
		return update_option( $option_key,$newvalue,$autoload );
	}
	else{
		return update_blog_option( get_current_blog_id(),$option_key,$newvalue );
	}
}

//Return default deck options
function eos_cards_default_deck_options(){
	return array(
		'def-back-card-choice' => 1,
		'custom_back_card_id' => 0,
		'card_width' => 150,
		'card_height' => 225
	);
}
//Return CSS property adding -o, -ms, -moz, -webkit
function eos_cards_add_css_prefixes( $prop,$value ){
	$props = array();
	foreach( array( '-o-','-ms-','-moz-','-webkit-','' ) as $prefix ){
		$props[] = $prefix.$prop.':'.$value.';';
	}
	return implode( ';',$props );
}

//Enqueue shortcode script
function eos_cards_sht_script( $atts,$default_atts,$admin_preview,$w,$ratio ){
	extract( shortcode_atts( $default_atts, $atts ) );
	if( !( isset( $_REQUEST['action'] ) && 'elementor' === $_REQUEST['action'] ) ){
		wp_enqueue_script( 'eos-cards-main',EOS_CARDS_ASSETS_URL.'/js/oc-cards.min.js',array( 'jquery' ) );
		$params = array(
			'type' => esc_attr( $deck_type ),
			'card_width' => absint( $w ),
			'ratio' => esc_attr( $ratio ),
			'direction' => is_rtl() ? 'right' : 'left',
			'show_title' => 'true' !== $show_title ? 'false' : 'true',
			'title_alignment' => in_array( $title_alignment,array( 'left','center','right' ) ) ? $title_alignment : 'initial',
			'ajax_loader' => EOS_CARDS_ASSETS_URL.'/img/ajax-loader.gif',
			'ajaxurl' => admin_url( 'admin-ajax.php' ),
			'is_admin_preview' => $admin_preview,
			'deck_from' => absint( $deck_from )
		);
		wp_localize_script( 'eos-cards-main','eos_cards_js',$params );
	}
}

//Return array of default shortcode attributes
function eos_cards_default_atts(){
	$default_opts = eos_cards_default_deck_options();
	return array(
		'back_border_color' => '',
		'back_border' => 'no',
		'border_radius' => '',
		'button_text_mix' => esc_html__( 'Mix the cards','oracle-cards' ),
		'button_text_pick' => esc_html__( 'Pick your card','oracle-cards' ),
		'def-back-card-choice' => 1,
		'card_height' => $default_opts['card_height'],
		'card_width' => $default_opts['card_width'],
		'class' => '',
		'custom_back_id' => '',
		'deck_from' => 930,
		'deck_type' => 'folding_fan',
		'deck' => 'none',
		'distance' => 2,
		'elementor' => 'false',
		'maxmargin' => 400,
		'maxnumber' => 100,
		'maxrand' => 100,
		'on_mobile' => 'show',
		'show_title' => 'false',
		'space_top_button' => 20,
		'space_top_text' => 20,
		'space_top' => 20,
		'title_alignment' => 'initial'
	);
}
